@@ -9,7 +9,7 @@ pub struct CreateRequest {
     pub currency: Currency,
 }
 
-pub trait Server<T: Context>: ContextProvider<T> {
+pub trait Server<'a, T: Context>: ContextProvider<'a, T> {
     type Context: ServerContext;
     fn api_description() -> ApiDescription<Self::Context>;
     fn new_server(self, bind_address: &str) -> Result<HttpServerStarter<Self::Context>, Error>;
